@@ -68,7 +68,7 @@ class CatBoostAlgorithm(BaseAlgorithm):
 
         logger.debug("CatBoostAlgorithm.__init__")
 
-    def _assess_iterations(self, X, y, eval_set, max_time):
+    def _assess_iterations(self, X, y, eval_set, max_time = None):
         if max_time is None:
             max_time = 3600
         try:
@@ -85,8 +85,8 @@ class CatBoostAlgorithm(BaseAlgorithm):
                 verbose_eval=False,
             )
             elapsed_time = np.round(time.time() - start_time, 2)
-            new_rounds = int(min(10000, max_time / elapsed_time * 2.0))
-            new_rounds = max(max_rounds, 100)
+            new_rounds = int(min(10000, max_time / elapsed_time))
+            new_rounds = max(max_rounds, 10)
             return new_rounds
         except Exception as e:
             return 1000
@@ -121,8 +121,10 @@ class CatBoostAlgorithm(BaseAlgorithm):
                 weight=sample_weight_validation,
             )
 
-        new_iterations = self._assess_iterations(X, y, eval_set, max_time)
+        # disable for now ...
+        new_iterations = self._assess_iterations(X, y, eval_set, max_time = None)
         self.model.set_params(iterations=new_iterations)
+        #self.model.set_params(iterations=self.rounds)
 
         self.model.fit(
             X,
@@ -249,12 +251,12 @@ AlgorithmsRegistry.add(
 multiclass_classification_params = copy.deepcopy(classification_params)
 multiclass_classification_params["loss_function"] = ["MultiClass"]
 multiclass_classification_params["depth"] = [3, 4, 5, 6]
-multiclass_classification_params["learning_rate"] = [0.1, 0.2]
+multiclass_classification_params["learning_rate"] = [0.1, 0.15, 0.2]
 
 multiclass_classification_default_params = copy.deepcopy(classification_default_params)
 multiclass_classification_default_params["loss_function"] = "MultiClass"
 multiclass_classification_default_params["depth"] = 5
-multiclass_classification_default_params["learning_rate"] = 0.1
+multiclass_classification_default_params["learning_rate"] = 0.15
 
 
 AlgorithmsRegistry.add(
@@ -268,6 +270,7 @@ AlgorithmsRegistry.add(
 
 regression_params = copy.deepcopy(classification_params)
 regression_params["loss_function"] = ["RMSE", "MAE"]
+regression_params["learning_rate"] = [0.1, 0.15, 0.2]
 
 regression_required_preprocessing = [
     "missing_values_inputation",
@@ -278,7 +281,7 @@ regression_required_preprocessing = [
 
 
 regression_default_params = {
-    "learning_rate": 0.1,
+    "learning_rate": 0.15,
     "depth": 6,
     "rsm": 1,
     "loss_function": "RMSE",
