@@ -18,26 +18,26 @@ class MetricException(Exception):
         log.error(message)
 
 
-def logloss(y_true, y_predicted):
+def logloss(y_true, y_predicted, sample_weight=None):
     epsilon = 1e-6
     y_predicted = sp.maximum(epsilon, y_predicted)
     y_predicted = sp.minimum(1 - epsilon, y_predicted)
-    ll = log_loss(y_true, y_predicted)
+    ll = log_loss(y_true, y_predicted, sample_weight=sample_weight)
     return ll
 
 
-def rmse(y_true, y_predicted):
-    val = mean_squared_error(y_true, y_predicted)
+def rmse(y_true, y_predicted, sample_weight=None):
+    val = mean_squared_error(y_true, y_predicted, sample_weight=sample_weight)
     return np.sqrt(val) if val > 0 else -np.Inf
 
 
-def negative_auc(y_true, y_predicted):
-    val = roc_auc_score(y_true, y_predicted)
+def negative_auc(y_true, y_predicted, sample_weight=None):
+    val = roc_auc_score(y_true, y_predicted, sample_weight=sample_weight)
     return -1.0 * val
 
 
-def negative_r2(y_true, y_predicted):
-    val = r2_score(y_true, y_predicted)
+def negative_r2(y_true, y_predicted, sample_weight=None):
+    val = r2_score(y_true, y_predicted, sample_weight=sample_weight)
     return -1.0 * val
 
 
@@ -49,6 +49,7 @@ class Metric(object):
         self.name = self.params.get("name")
         if self.name is None:
             raise MetricException("Metric name not defined")
+
         self.minimize_direction = self.name in [
             "logloss",
             "auc",  # negative auc
@@ -74,9 +75,8 @@ class Metric(object):
         else:
             raise MetricException(f"Unknown metric '{self.name}'")
 
-    def __call__(self, y_true, y_predicted):
-
-        return self.metric(y_true, y_predicted)
+    def __call__(self, y_true, y_predicted, sample_weight=None):
+        return self.metric(y_true, y_predicted, sample_weight=sample_weight)
 
     def improvement(self, previous, current):
         if self.minimize_direction:
